# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.organizations_component_config import OrganizationsComponentConfig
from neurograph.v1.models.organizations_generation_metadata import OrganizationsGenerationMetadata
from neurograph.v1.models.organizations_spacing_config import OrganizationsSpacingConfig
from neurograph.v1.models.organizations_typography_config import OrganizationsTypographyConfig
from typing import Optional, Set
from typing_extensions import Self

class OrganizationsBrandDetailResponse(BaseModel):
    """
    OrganizationsBrandDetailResponse
    """ # noqa: E501
    accessibility_level: Optional[StrictStr] = None
    background_img_url: Optional[StrictStr] = None
    color1: Optional[StrictStr] = None
    color2: Optional[StrictStr] = None
    color3: Optional[StrictStr] = None
    color4: Optional[StrictStr] = None
    color5: Optional[StrictStr] = None
    components: Optional[OrganizationsComponentConfig] = None
    dark_mode_enabled: Optional[StrictBool] = None
    error: Optional[StrictStr] = None
    generation_metadata: Optional[OrganizationsGenerationMetadata] = None
    is_ai_generated: Optional[StrictBool] = None
    logo_img_url: Optional[StrictStr] = None
    org_guid: Optional[StrictStr] = None
    primary_color: Optional[StrictStr] = None
    secondary_color: Optional[StrictStr] = None
    spacing: Optional[OrganizationsSpacingConfig] = None
    tertiary_color: Optional[StrictStr] = None
    typography: Optional[OrganizationsTypographyConfig] = None
    version: Optional[StrictInt] = Field(default=None, description="New fields - Phase 4")
    __properties: ClassVar[List[str]] = ["accessibility_level", "background_img_url", "color1", "color2", "color3", "color4", "color5", "components", "dark_mode_enabled", "error", "generation_metadata", "is_ai_generated", "logo_img_url", "org_guid", "primary_color", "secondary_color", "spacing", "tertiary_color", "typography", "version"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OrganizationsBrandDetailResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of components
        if self.components:
            _dict['components'] = self.components.to_dict()
        # override the default output from pydantic by calling `to_dict()` of generation_metadata
        if self.generation_metadata:
            _dict['generation_metadata'] = self.generation_metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of spacing
        if self.spacing:
            _dict['spacing'] = self.spacing.to_dict()
        # override the default output from pydantic by calling `to_dict()` of typography
        if self.typography:
            _dict['typography'] = self.typography.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OrganizationsBrandDetailResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "accessibility_level": obj.get("accessibility_level"),
            "background_img_url": obj.get("background_img_url"),
            "color1": obj.get("color1"),
            "color2": obj.get("color2"),
            "color3": obj.get("color3"),
            "color4": obj.get("color4"),
            "color5": obj.get("color5"),
            "components": OrganizationsComponentConfig.from_dict(obj["components"]) if obj.get("components") is not None else None,
            "dark_mode_enabled": obj.get("dark_mode_enabled"),
            "error": obj.get("error"),
            "generation_metadata": OrganizationsGenerationMetadata.from_dict(obj["generation_metadata"]) if obj.get("generation_metadata") is not None else None,
            "is_ai_generated": obj.get("is_ai_generated"),
            "logo_img_url": obj.get("logo_img_url"),
            "org_guid": obj.get("org_guid"),
            "primary_color": obj.get("primary_color"),
            "secondary_color": obj.get("secondary_color"),
            "spacing": OrganizationsSpacingConfig.from_dict(obj["spacing"]) if obj.get("spacing") is not None else None,
            "tertiary_color": obj.get("tertiary_color"),
            "typography": OrganizationsTypographyConfig.from_dict(obj["typography"]) if obj.get("typography") is not None else None,
            "version": obj.get("version")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.signal_client_info import SignalClientInfo
from neurograph.v1.models.signal_client_signal_totals import SignalClientSignalTotals
from neurograph.v1.models.signal_daily_intent_band import SignalDailyIntentBand
from neurograph.v1.models.signal_daily_purchase_metrics import SignalDailyPurchaseMetrics
from neurograph.v1.models.signal_date_range import SignalDateRange
from neurograph.v1.models.signal_persona_conversion import SignalPersonaConversion
from typing import Optional, Set
from typing_extensions import Self

class SignalClientSignalDetailsResponse(BaseModel):
    """
    SignalClientSignalDetailsResponse
    """ # noqa: E501
    cached: Optional[StrictBool] = None
    client_info: Optional[SignalClientInfo] = None
    daily_intent: Optional[List[SignalDailyIntentBand]] = None
    daily_purchases: Optional[List[SignalDailyPurchaseMetrics]] = None
    date_range: Optional[SignalDateRange] = None
    error: Optional[StrictStr] = None
    persona_breakdown: Optional[List[SignalPersonaConversion]] = None
    query_time_ms: Optional[StrictInt] = None
    totals: Optional[SignalClientSignalTotals] = None
    __properties: ClassVar[List[str]] = ["cached", "client_info", "daily_intent", "daily_purchases", "date_range", "error", "persona_breakdown", "query_time_ms", "totals"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SignalClientSignalDetailsResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of client_info
        if self.client_info:
            _dict['client_info'] = self.client_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in daily_intent (list)
        _items = []
        if self.daily_intent:
            for _item_daily_intent in self.daily_intent:
                if _item_daily_intent:
                    _items.append(_item_daily_intent.to_dict())
            _dict['daily_intent'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in daily_purchases (list)
        _items = []
        if self.daily_purchases:
            for _item_daily_purchases in self.daily_purchases:
                if _item_daily_purchases:
                    _items.append(_item_daily_purchases.to_dict())
            _dict['daily_purchases'] = _items
        # override the default output from pydantic by calling `to_dict()` of date_range
        if self.date_range:
            _dict['date_range'] = self.date_range.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in persona_breakdown (list)
        _items = []
        if self.persona_breakdown:
            for _item_persona_breakdown in self.persona_breakdown:
                if _item_persona_breakdown:
                    _items.append(_item_persona_breakdown.to_dict())
            _dict['persona_breakdown'] = _items
        # override the default output from pydantic by calling `to_dict()` of totals
        if self.totals:
            _dict['totals'] = self.totals.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SignalClientSignalDetailsResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "cached": obj.get("cached"),
            "client_info": SignalClientInfo.from_dict(obj["client_info"]) if obj.get("client_info") is not None else None,
            "daily_intent": [SignalDailyIntentBand.from_dict(_item) for _item in obj["daily_intent"]] if obj.get("daily_intent") is not None else None,
            "daily_purchases": [SignalDailyPurchaseMetrics.from_dict(_item) for _item in obj["daily_purchases"]] if obj.get("daily_purchases") is not None else None,
            "date_range": SignalDateRange.from_dict(obj["date_range"]) if obj.get("date_range") is not None else None,
            "error": obj.get("error"),
            "persona_breakdown": [SignalPersonaConversion.from_dict(_item) for _item in obj["persona_breakdown"]] if obj.get("persona_breakdown") is not None else None,
            "query_time_ms": obj.get("query_time_ms"),
            "totals": SignalClientSignalTotals.from_dict(obj["totals"]) if obj.get("totals") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.shopify_store_detail import ShopifyStoreDetail

class TestShopifyStoreDetail(unittest.TestCase):
    """ShopifyStoreDetail unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ShopifyStoreDetail:
        """Test ShopifyStoreDetail
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ShopifyStoreDetail`
        """
        model = ShopifyStoreDetail()
        if include_optional:
            return ShopifyStoreDetail(
                client_id = '',
                domain = '',
                id = 56,
                ingested_at = '',
                myshopify_domain = '',
                name = '',
                shopify_updated_at_ms = 56,
                updated_at_ms = 56
            )
        else:
            return ShopifyStoreDetail(
        )
        """

    def testShopifyStoreDetail(self):
        """Test ShopifyStoreDetail"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
